==> gulp-webdriver-1.0.0.tgz: package/index.js <==
'use strict';

var path = require('path'),
    fs = require('fs'),
    through = require('through2'),
    dargs = require('dargs'),
    gutil = require('gulp-util'),
    spawn = require('child_process').spawn,
    deepmerge = require('deepmerge');

module.exports = function(options) {
    return through.obj(function(file, enc, done) {

        var stream = this,
            configFile = file.path,
            base = process.cwd(),
            wdioBin = path.join(base, 'node_modules', 'webdriverio', 'bin') + '/wdio';

        var opts = deepmerge({
            wdioBin: wdioBin
        }, options);

        /**
         * check webdriverio dependency
         */
        if (!fs.existsSync(opts.wdioBin)) {
            return this.emit('error', new gutil.PluginError('gulp-webdriver', 'Haven\'t found the WebdriverIO test runner', {
                showStack: false
            }));
        }

        var args = process.execArgv.concat([configFile]).concat(dargs(opts, {
            excludes: ['wdioBin'],
            keepCamelCase: true
        }));

        gutil.log('spawn wdio with these attributes:\n', args.join('\n'));
        var wdio = spawn(opts.wdioBin, args, {
            stdio: 'inherit'
        });

        wdio.on('exit', function(code) {
            gutil.log('wdio testrunner finished with exit code', code);

            if (code !== 0) {
                stream.emit('error', new gutil.PluginError('gulp-webdriver', 'wdio excited with code ' + code, {
                    showStack: false
                }));
            }

            done();
            done = null;
        });

        return stream;
    });
};

==> gulp-webdriver-1.0.1.tgz: package/index.js <==
'use strict';

var path = require('path'),
    fs = require('fs'),
    through = require('through2'),
    dargs = require('dargs'),
    gutil = require('gulp-util'),
    spawn = require('child_process').spawn,
    deepmerge = require('deepmerge');

module.exports = function(options) {
    return through.obj(function(file, enc, done) {

        var stream = this,
            configFile = file.path,
            isWin = /^win/.test(process.platform),
            wdioBin = path.join(__dirname, 'node_modules', '.bin', isWin ? 'wdio.cmd' : 'wdio');

        var opts = deepmerge({
            wdioBin: wdioBin
        }, options || {});

        /**
         * check webdriverio dependency
         */
        if (!fs.existsSync(opts.wdioBin)) {
            return this.emit('error', new gutil.PluginError('gulp-webdriver', 'Haven\'t found the WebdriverIO test runner', {
                showStack: false
            }));
        }

        var args = process.execArgv.concat([configFile]).concat(dargs(opts, {
            excludes: ['wdioBin'],
            keepCamelCase: true
        }));

        gutil.log('spawn wdio with these attributes:\n', args.join('\n'));
        var wdio = spawn(opts.wdioBin, args, {
            stdio: 'inherit'
        });

        wdio.on('exit', function(code) {
            gutil.log('wdio testrunner finished with exit code', code);

            if (code !== 0) {
                stream.emit('error', new gutil.PluginError('gulp-webdriver', 'wdio excited with code ' + code, {
                    showStack: false
                }));
            }

            done();
            done = null;
        });

        return stream;
    });
};
